Package 'pkgdownTemplate'

Title: pkgdown Template Package
Description: This is a template package for a NMFS branded R package with a pkgdown website.
Authors: Elizabeth Holmes [aut, cre], Bai Li [aut], Christine Stawitz [aut]
Maintainer: Elizabeth Holmes <[email protected]>
License: GPL-3 + file LICENSE
Version: 1.0
Built: 2026-05-16 08:09:52 UTC
Source: https://github.com/jimianelli/popcie

Help Index


Sample Function Title

Description

This part is the description. It can be as long as you want but usually is one paragraph.

Usage

samplefunction(x, y = 10, z = c("yellow", "red", "green"))

Arguments

x

This is a required argument and has no default value.

y

Has a default value of 10.

z

Although this looks like it is a default string, the function match.arg() is used to set it in the function. With match.arg(), the string specifies what values are allowed and it will throw an error if not one of those. The default is the first value.

Value

A string with the values.

Examples

samplefunction(1)

Sample plot

Description

This shows how you need to use :: with all your functions that are not in base R.

Usage

sampleplot(x, y)

Arguments

x

The x variables.

y

The y response values.

Value

the coefficient of the linear regression

Examples

x <- 1:10
y <- 10+3*x + stats::rnorm(10, 0, 10)
sampleplot(x, y)