| Title: | pkgdown Template Package |
|---|---|
| Description: | This is a template package for a NMFS branded R package with a pkgdown website. |
| Authors: | Elizabeth Holmes [aut, cre], Bai Li [aut], Christine Stawitz [aut] |
| Maintainer: | Elizabeth Holmes <[email protected]> |
| License: | GPL-3 + file LICENSE |
| Version: | 1.0 |
| Built: | 2026-05-16 08:09:52 UTC |
| Source: | https://github.com/jimianelli/popcie |
This part is the description. It can be as long as you want but usually is one paragraph.
samplefunction(x, y = 10, z = c("yellow", "red", "green"))samplefunction(x, y = 10, z = c("yellow", "red", "green"))
x |
This is a required argument and has no default value. |
y |
Has a default value of 10. |
z |
Although this looks like it is a default string, the function |
A string with the values.
samplefunction(1)samplefunction(1)
This shows how you need to use :: with all your functions that are not in base R.
sampleplot(x, y)sampleplot(x, y)
x |
The x variables. |
y |
The y response values. |
the coefficient of the linear regression
x <- 1:10 y <- 10+3*x + stats::rnorm(10, 0, 10) sampleplot(x, y)x <- 1:10 y <- 10+3*x + stats::rnorm(10, 0, 10) sampleplot(x, y)